@@ -2,7 +2,7 @@ from enum import Enum
 from typing import Any, Dict, List, Union
 
 from .api_client import ApiVersion, NutanixApiClient
-from .api_object import Metadata, Spec, Status, V3ApiObject
+from .entity import Entity, Metadata, Spec, Status
 
 
 class PowerState(Enum):
@@ -15,6 +15,16 @@ class VMMetadata(Metadata):
         super().__init__(metadata)
 
 
+class VMBootDevices(Enum):
+    CDROM = "CDROM"
+    DISK = "DISK"
+    NETWORK = "NETWORK"
+
+    @classmethod
+    def default_boot_order(cls) -> List["VMBootDevices"]:
+        return [VMBootDevices.CDROM, VMBootDevices.DISK, VMBootDevices.NETWORK]
+
+
 class VMSpec(Spec):
     def __init__(self, spec: Dict[str, Any]) -> None:
         super().__init__(spec)
@@ -64,6 +74,14 @@ class VMSpec(Spec):
     def boot_config(self) -> Dict[str, Any]:
         return self.resources.get("boot_config")
 
+    @property
+    def boot_device_order(self) -> List[str]:
+        return self.boot_config.get("boot_device_order_list")
+
+    @boot_device_order.setter
+    def boot_device_order(self, boot_devices: List[VMBootDevices]):
+        self.boot_config["boot_device_order_list"] = [device.value for device in boot_devices]
+
     @property
     def power_state(self) -> str:
         return self.resources.get("power_state")
@@ -126,7 +144,7 @@ class NutanixVMLabel:
         return NutanixVMLabel(**response)
 
 
-class NutanixVM(V3ApiObject):
+class NutanixVM(Entity):
     status: VMStatus
     spec: VMSpec
     metadata: VMMetadata
@@ -157,24 +175,27 @@ class NutanixVM(V3ApiObject):
     def ip_addresses(self) -> List[str]:
         return self.spec.ip_endpoint_list
 
+    @classmethod
+    def list_entities(cls, api_client: NutanixApiClient, get_all: bool = True) -> List["NutanixVM"]:
+        return super().list_entities(api_client, get_all)
+
     @property
     def num_sockets(self) -> int:
         return self.spec.sockets
 
-    @classmethod
-    def set_vms_power_state(cls, api_client: NutanixApiClient, uuid: str, state: PowerState):
-        vm = cls.get(api_client, uuid)
-        vm.power_state = state
-        vm_info = vm.get_info()
+    def power_off(self, wait: bool = True):
+        self.load(self.uuid)
+        self.spec.power_state = PowerState.OFF
+        return self.update_entity(wait)
 
-        del vm_info["status"]
-        return api_client.PUT(f"/{cls.base_route}/{uuid}", body=vm_info)
-
-    def power_off(self):
-        return self.set_vms_power_state(self._api_client, self.uuid, PowerState.OFF)
-
-    def power_on(self):
-        return self.set_vms_power_state(self._api_client, self.uuid, PowerState.ON)
+    def power_on(self, wait: bool = True):
+        self.load(self.uuid)
+        self.spec.power_state = PowerState.ON
+        return self.update_entity(wait)
 
     def reboot(self):
         return self._api_client.POST(f"/{self.base_route}/{self.uuid}/acpi_reboot")
+
+    def update_boot_order(self, vm_boot_devices: List[VMBootDevices], wait: bool = True):
+        self.spec.boot_device_order = vm_boot_devices
+        return self.update_entity(wait)
